@@ -111,9 +111,11 @@ types_converter_dict = {
             "jsonb": "String",
             "json": "String",
             "varchar": "String",
+            "array": "String",
             "interval": "String",
             "character varying": "String",
             "boolean": "String",
+            "hstore": "String",
             "timestamp": "Datetime",
             "timestamp without time zone": "Datetime",
             "time without time zone": "String",
