@@ -1,24 +1,12 @@
 from converter.database_worker import DataBaseWorker
 from converter.config.config_converter import base_converter_params
 import logging
+import warnings
 import sys
 import json
-import warnings
 
 warnings.filterwarnings("ignore")
 
-logging.basicConfig(
-    stream=sys.stdout,
-    level=logging.INFO,
-    format="%(asctime)s  %(name)s  %(levelname)s: %(message)s",
-)
-logging.basicConfig(
-    stream=sys.stderr,
-    level=logging.ERROR,
-    format="%(asctime)s  %(name)s  %(levelname)s: %(message)s",
-)
-logging.captureWarnings(True)
-
 
 def save_ddl_to_file(ddl, table_name, ddl_dir):
     """
@@ -27,7 +15,10 @@ def save_ddl_to_file(ddl, table_name, ddl_dir):
     :param ddl_dir:
     :return:
     """
-    f = open(ddl_dir + "/" + table_name + ".sql", "w", )
+    f = open(
+        ddl_dir + "/" + table_name + ".sql",
+        "w",
+    )
     f.write(ddl)
     f.close()
 
@@ -44,6 +35,12 @@ class FieldsConverterOneWay:
         :param debug: show debug text
         :param tables:  converter only for list of tables. Will process more rapid
         """
+        log_format = "%(asctime)-15s %(name)s:%(levelname)s: %(message)s"
+        logging.basicConfig(format=log_format, stream=sys.stdout, level=logging.INFO)
+        logging.basicConfig(format=log_format, stream=sys.stderr, level=logging.ERROR)
+        logging.captureWarnings(True)
+        self.logger = logging.getLogger(__class__.__name__)
+
         if sql_credentials is not None:
             self.db_worker = DataBaseWorker(sql_credentials, db, debug, tables)
         else:
@@ -65,10 +62,6 @@ class FieldsConverterOneWay:
     def __del__(self):
         del self.db_worker
 
-    def log(self, text):
-        if self.debug:
-            logging.info(self.__str__ + ": " + text)
-
     def __get_python_type(self, type_sql):
         """
         Get type to convert in python
@@ -113,15 +106,19 @@ class FieldsConverterOneWay:
                 dataframe[key] = dataframe[key].replace(to_replace=dict_replace_str)
         return dataframe
 
-    def __update_value_type(self, fields, item, key, dict_replace_str={}):
+    def __update_value_type(
+            self, fields, item, key, dict_replace_str={}, json_fields=None
+    ):
         """
         :param dict_replace_str: - replace params to
-        :param db: db to update
+        :param amocrm.db: amocrm.db to update
         :param fields: dict - key  type
         :param item: - to update item
         :param key: key to update
+        :param json_fields: fields that need to make as valid json
         :return: converted item
         """
+        json_fields = json_fields or []
 
         if item is None:
             return item
@@ -135,13 +132,16 @@ class FieldsConverterOneWay:
             item[key] = int(item[key])
         elif type_python == "float":
             item[key] = float(item[key])
-        elif type_python == "json":
+        elif type_python == "json" or key in json_fields:
             try:
                 item[key] = json.dumps(item[key], ensure_ascii=False)
             except (TypeError, ValueError):
                 item[key] = item[key]
         elif type_python == "bool":
             item[key] = bool(item[key])
+        elif type_python == "datetime":
+            from dateutil import parser
+            item[key] = parser.parse(str(item[key]))
         else:
             item[key] = str(item[key])
             for key_replace in dict_replace_str:
@@ -150,8 +150,11 @@ class FieldsConverterOneWay:
                 )
         return item
 
-    def update_value_type(self, table_name, items, dict_replace_str={}, fields=None):
+    def update_value_type(
+            self, table_name, items, dict_replace_str={}, fields=None, json_fields=None
+    ):
         """
+        :param json_fields:
         :param fields:
         :param dict_replace_str: replace in string dict
         :param items: list of dicts to update
@@ -164,9 +167,12 @@ class FieldsConverterOneWay:
         keys = fields.keys()
         for item in items:
             for key in keys:
-
                 item = self.__update_value_type(
-                    fields, item, key, dict_replace_str=dict_replace_str
+                    fields,
+                    item,
+                    key,
+                    dict_replace_str=dict_replace_str,
+                    json_fields=json_fields,
                 )
         return items
 
@@ -186,7 +192,7 @@ class FieldsConverterOneWay:
         txt += ")"
         if to_create:
             self.conn.execute(txt)
-            logging.info("creating table {} is successful".format(table_name))
+            self.logger.info("creating table {} is successful".format(table_name))
         if ddl_dir is not None:
             save_ddl_to_file(ddl=txt, ddl_dir=ddl_dir, table_name=table_name)
         return txt
@@ -208,7 +214,7 @@ class FieldsConverterOneWay:
         txt += ")"
         if to_create:
             self.conn.execute(txt)
-            logging.info("creating table {} is successful".format(table_name))
+            self.logger.info("creating table {} is successful".format(table_name))
         if ddl_dir is not None:
             save_ddl_to_file(ddl=txt, ddl_dir=ddl_dir, table_name=table_name)
-        return txt
\ No newline at end of file
+        return txt
